Package: canceR
Type: Package
Title: A Graphical User Interface for accessing and modeling the Cancer
        Genomics Data of MSKCC
Version: 1.46.0
Date: 2024-02-28
Author: Karim Mezhoud. Nuclear Safety & Security Department. Nuclear
        Science Center of Tunisia.
Maintainer: Karim Mezhoud <kmezhoud@gmail.com>
Description: The package is user friendly interface based on the cgdsr
        and other modeling packages to explore, compare, and analyse
        all available Cancer Data (Clinical data, Gene Mutation, Gene
        Methylation, Gene Expression, Protein Phosphorylation, Copy
        Number Alteration) hosted by the Computational Biology Center
        at Memorial-Sloan-Kettering Cancer Center (MSKCC).
License: GPL-2
LazyLoad: yes
Depends: R (>= 4.3), tcltk, cBioPortalData
Imports: GSEABase, tkrplot, geNetClassifier, RUnit, Formula, rpart,
        survival, Biobase, phenoTest, circlize, plyr, tidyr, dplyr,
        graphics, stats, utils, grDevices, R.oo, R.methodsS3
Suggests: testthat (>= 3.1), knitr, rmarkdown, BiocStyle
SystemRequirements: Tktable, BWidget
VignetteBuilder: knitr
BugReports: https://github.com/kmezhoud/canceR/issues
biocViews: GUI, GeneExpression, Clustering, GO, GeneSetEnrichment,
        KEGG, MultipleComparison
RoxygenNote: 7.3.1
Encoding: UTF-8
Config/pak/sysreqs: bwidget cmake make libbz2-dev libicu-dev
        liblzma-dev libpng-dev libsecret-1-dev libuv1-dev libxml2-dev
        libssl-dev tk-table libx11-dev xz-utils zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:40:43 UTC
RemoteUrl: https://github.com/bioc/canceR
RemoteRef: RELEASE_3_23
RemoteSha: 359ae9800ccd67c8a09f59936e63bd89aecfc62a
NeedsCompilation: no
Packaged: 2026-04-29 18:40:01 UTC; root
Built: R 4.6.0; ; 2026-04-29 20:25:16 UTC; unix
