# Generated by roxygen2: do not edit by hand

S3method(cbind,na)
S3method(rbind,na)
export(CGDS)
export(Match_GeneList_MSigDB)
export(Run.GSEA)
export(UnifyRowNames)
export(about)
export(canceR)
export(canceR_Issue)
export(canceR_Vignette)
export(dialogGeneClassifier)
export(dialogMetOption)
export(dialogMut)
export(dialogOptionCircos)
export(dialogOptionGSEAlm)
export(dialogOptionPhenoTest)
export(dialogPlotOption_SkinCor)
export(dialogSamplingGSEA)
export(dialogSelectFiles_GSEA)
export(dialogSpecificMut)
export(dialogSummary_GSEA)
export(dialoggetGeneListMSigDB)
export(displayInTable)
export(getCases)
export(getCasesGenProfs)
export(getCircos)
export(getClinicData_MultipleCases)
export(getClinicalDataMatrix)
export(getFreqMutData)
export(getGCTCLSExample)
export(getGCT_CLSfiles)
export(getGSEAlm_Diseases)
export(getGSEAlm_Variables)
export(getGenProfs)
export(getGeneExpMatrix)
export(getGeneList)
export(getGeneListExample)
export(getGeneListFromMSigDB)
export(getGenesClassifier)
export(getGenesTree_MultipleCases)
export(getGenesTree_SingleCase)
export(getInTable)
export(getMSigDB)
export(getMSigDBExample)
export(getMSigDBfile)
export(getMegaProfData)
export(getMetDataMultipleGenes)
export(getMutData)
export(getPhenoTest)
export(getProfData)
export(getProfilesDataMultipleGenes)
export(getProfilesDataSingleGene)
export(getSpecificMut)
export(getSummaryGSEA)
export(getSurvival)
export(getTextWin)
export(geteSet)
export(modalDialog)
export(plotModel)
export(plot_1Gene_2GenProfs)
export(plot_2Genes_1GenProf)
export(setWorkspace)
export(test.CGDS)
export(testCheckedCaseGenProf)
import(Formula)
import(R.oo)
import(RUnit)
import(cBioPortalData)
import(circlize)
import(plyr)
import(rpart)
import(tcltk)
import(tkrplot)
importFrom(Biobase,ExpressionSet)
importFrom(Biobase,exprs)
importFrom(Biobase,openPDF)
importFrom(Biobase,pData)
importFrom(Biobase,varLabels)
importFrom(GSEABase,GeneSet)
importFrom(GSEABase,GeneSetCollection)
importFrom(R.methodsS3,setMethodS3)
importFrom(geNetClassifier,calculateGenesRanking)
importFrom(geNetClassifier,genesDetails)
importFrom(grDevices,colors)
importFrom(grDevices,dev.cur)
importFrom(grDevices,dev.new)
importFrom(grDevices,dev.off)
importFrom(grDevices,graphics.off)
importFrom(grDevices,jpeg)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,rainbow)
importFrom(grDevices,savePlot)
importFrom(graphics,axis)
importFrom(graphics,image)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(phenoTest,ExpressionPhenoTest)
importFrom(phenoTest,getFc)
importFrom(phenoTest,getSignif)
importFrom(stats,as.formula)
importFrom(stats,cor)
importFrom(stats,density)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.exclude)
importFrom(stats,p.adjust)
importFrom(stats,pnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,window)
importFrom(survival,Surv)
importFrom(survival,cox.zph)
importFrom(survival,coxph)
importFrom(survival,survfit)
importFrom(utils,browseURL)
importFrom(utils,capture.output)
importFrom(utils,memory.limit)
importFrom(utils,read.delim)
importFrom(utils,read.table)
importFrom(utils,vignette)
importFrom(utils,write.table)
