# to avoid 'no visible binding for global variable' NOTE
globalVariables(c("Li","A","EventTime","Category", "Continu", "Category",
                  "ttMain", "x", "fname.GCT", "fname.CLS", "mSigDB_SubName",
                  "GenesDetails", "CaseChoice", "ListProfData", "ListMetData",
                  "ListMutData", "lenght", "myGlobalEnv", "MSigDB", "MSigDBFile",
                  "fname.MSigDB", "age", "CasesStudies", "curselectCases", "devSVG",
                  "ttCasesGenProfs", "cbind2", "new", "rbind2", "vignette", "pull",
                  "select", "across", "left_join", "all_of", "p", "getProfileData",
                  "getClinicalData", "GSEA", "Run.GSEA", "everything"))