\name{GSEA.GeneRanking}
\alias{GSEA.GeneRanking}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
GSEA.GeneRanking
}
\description{
GSEA.GeneRanking
}

%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{A}{
%%     ~~Describe \code{A} here~~
}
  \item{class.labels}{
%%     ~~Describe \code{class.labels} here~~
}
  \item{gene.labels}{
%%     ~~Describe \code{gene.labels} here~~
}
  \item{nperm}{
%%     ~~Describe \code{nperm} here~~
}
  \item{permutation.type}{
%%     ~~Describe \code{permutation.type} here~~
}
  \item{sigma.correction}{
%%     ~~Describe \code{sigma.correction} here~~
}
  \item{fraction}{
%%     ~~Describe \code{fraction} here~~
}
  \item{replace}{
%%     ~~Describe \code{replace} here~~
}
  \item{reverse.sign}{
%%     ~~Describe \code{reverse.sign} here~~
}
}
\value{
GSEA.GeneRanking
}

\examples{
\dontrun{
library(canceR)
## Load workspace
readRDS(paste(path.package("canceR"),"/extdata/rdata/ucec_tcga_pubGSEA1021.rds", sep=""))
##Run.GSEA()
}
}