\name{GSEA.Threshold}
\alias{GSEA.Threshold}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
GSEA.Threshold
}
\description{
GSEA.Threshold
}
\usage{
GSEA.Threshold(V, thres, ceil)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{V}{
%%     ~~Describe \code{V} here~~
}
  \item{thres}{
%%     ~~Describe \code{thres} here~~
}
  \item{ceil}{
%%     ~~Describe \code{ceil} here~~
}
}

\value{
GSEA.Threshold
}
\examples{
## Load workspace
readRDS(paste(path.package("canceR"),"/extdata/rdata/ucec_tcga_pubGSEA1021.rds", sep=""))
\dontrun{

##Run.GSEA()
}
}