\name{GSEA.VarFilter}
\alias{GSEA.VarFilter}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
GSEA.VarFilter
}
\description{
GSEA.VarFilter
}
\usage{
GSEA.VarFilter(V, fold, delta, gene.names = "NULL")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{V}{
%%     ~~Describe \code{V} here~~
}
  \item{fold}{
%%     ~~Describe \code{fold} here~~
}
  \item{delta}{
%%     ~~Describe \code{delta} here~~
}
  \item{gene.names}{
%%     ~~Describe \code{gene.names} here~~
}
}
\value{
GSEA.VarFilter
}

\examples{
## Load workspace
readRDS(paste(path.package("canceR"),"/extdata/rdata/ucec_tcga_pubGSEA1021.rds", sep=""))
\dontrun{
##Run.GSEA()
}
}