\name{OLD.GSEA.EnrichmentScore}
\alias{OLD.GSEA.EnrichmentScore}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ 
OLD.GSEA.EnrichmentScore
}
\description{
OLD.GSEA.EnrichmentScore
}

%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{gene.list}{
%%     ~~Describe \code{gene.list} here~~
}
  \item{gene.set}{
%%     ~~Describe \code{gene.set} here~~
}
}
\value{
OLD.GSEA.EnchmentScore
}
\examples{
readRDS(paste(path.package("canceR"),"/extdata/rdata/ucec_tcga_pubGSEA1021.rds", sep=""))
\dontrun{
##Run.GSEA()
}
}