\name{GSEA.EnrichmentScore2}
\alias{GSEA.EnrichmentScore2}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
GSEA.EnrichmentScore2
}
\description{
GSEA.EnrichmentScore2
}
\usage{
GSEA.EnrichmentScore2(gene.list, gene.set, weighted.score.type = 1, correl.vector = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{gene.list}{
%%     ~~Describe \code{gene.list} here~~
}
  \item{gene.set}{
%%     ~~Describe \code{gene.set} here~~
}
  \item{weighted.score.type}{
%%     ~~Describe \code{weighted.score.type} here~~
}
  \item{correl.vector}{
%%     ~~Describe \code{correl.vector} here~~
}
}
\value{
GSEA.EnrichmentScore2
}
\examples{
\dontrun{
library(canceR)
## Load workspace
readRDS(paste(path.package("canceR"),"/extdata/rdata/ucec_tcga_pubGSEA1021.rds", sep=""))
##Run.GSEA()
}
}