\name{GSEA.Res2Frame}
\alias{GSEA.Res2Frame}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
GSEA.Res2Frame
}
\description{
GSEA.Res2Frame
}
\usage{
GSEA.Res2Frame(filename = "NULL")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{filename}{
%%     ~~Describe \code{filename} here~~
}
}
\value{
GSEA.NormalizeCols
}

\examples{
readRDS(paste(path.package("canceR"),"/extdata/rdata/ucec_tcga_pubGSEA1021.rds", sep=""))
\dontrun{
##Run.GSEA()
}
}