\name{GSEA.NormalizeRows}
\alias{GSEA.NormalizeRows}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
GSEA.NormalizeRows
}
\description{
GSEA.NormalizeRows
}
\usage{
GSEA.NormalizeRows(V)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{V}{
%%     ~~Describe \code{V} here~~
}
}

\value{
GSEA.NormalizeRows
}

\examples{
\dontrun{
library(canceR)
## Load workspace
readRDS(paste(path.package("canceR"),"/extdata/rdata/ucec_tcga_pubGSEA1021.rds", sep=""))
##Run.GSEA()
}
}