\name{myGlobalEnv}
\alias{myGlobalEnv}
\docType{data}
\title{
myGlobalEnv
}
\description{
Global environment to store canceR variables.
}

\format{
  The format is:
<environment: 0xb3eb240> 
}

\keyword{datasets}


\examples{
myGlobalEnv <- new.env(parent = emptyenv())
}