% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/canceR_vignette.R
\name{canceR_Issue}
\alias{canceR_Issue}
\title{canceR Report Issue}
\usage{
canceR_Issue()
}
\value{
link to github issues
}
\description{
canceR Report Issue
}
\examples{
\dontrun{
canceR_Issue()
}

}
