% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getCor_ExpCNAMet.R
\name{getCor_ExpCNAMet}
\alias{getCor_ExpCNAMet}
\title{Get gene correlation for multiple dimensions.}
\usage{
getCor_ExpCNAMet(ListMatrix, dimension)
}
\arguments{
\item{ListMatrix}{is a List of numeric matrices}

\item{dimension}{Exp,CNA, Met , miRNA , RPPA}
}
\value{
correlation matrix
}
\description{
Get gene correlation for multiple dimensions.
}
\examples{
readRDS(paste(path.package("canceR"),"/extdata/rdata/Circos.rds", sep=""))
\dontrun{
getListProfData()
getCor_ExpCNAMet(ENV$ListProfData$Expression, dimension="mRNA")
head(ENV$Cor_Exp)
}
}
