\name{GSEA.Gct2Frame2}
\alias{GSEA.Gct2Frame2}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
GSEA.Gct2Frame2
}
\description{
GSEA.Gct2Frame2
}
\usage{
GSEA.Gct2Frame2(filename = "NULL")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{filename}{
%%     ~~Describe \code{filename} here~~
}
}
\value{
GSEA.GCT2Frame2
}

\examples{
\dontrun{
library(canceR)
## Load workspace
readRDS(paste(path.package("canceR"),"/extdata/rdata/ucec_tcga_pubGSEA1021.rds", sep=""))
##Run.GSEA()
}
}