% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/about.R
\name{about}
\alias{about}
\title{about canceR}
\usage{
about()
}
\value{
dialig box with text
}
\description{
about canceR
}
\examples{
\dontrun{
about()
}

}
