% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dialogOptionPhenoTest.R
\name{dialogOptionPhenoTest}
\alias{dialogOptionPhenoTest}
\title{Checkbox to select variables from clinical data}
\usage{
dialogOptionPhenoTest(eSet)
}
\arguments{
\item{eSet}{Expression Set}
}
\value{
vectors: variables to test Survival status, AGE, p-value
}
\description{
Checkbox to select variables from clinical data
}
\examples{
readRDS(paste(path.package("canceR"),"/extdata/rdata/prad_michPhenoTest1021.rds", sep=""))
\dontrun{
dialogOptionPhenoTest(ENV$eSet)
}

}
